| CSeQTL_dataGen | R Documentation |
Simulates a gene/SNP pair with baseline covariates XX,
cell type compositions true_RHO, phased SNP genotypes true_SNP,
and total (TReC) and allele-specific read counts (ASReC) contained in dat.
CSeQTL_dataGen(
NN,
MAF,
true_BETA0 = log(1000),
true_KAPPA,
true_ETA,
true_PHI = 0.1,
true_PSI = 0.05,
prob_phased = 0.05,
true_ALPHA = NULL,
batch = 1,
RHO = NULL,
cnfSNP = FALSE,
show = TRUE
)
NN |
Positive integer for sample size. |
MAF |
Positive numeric value between 0 and 1 for the minor allele frequency to simulate phased SNP genotypes assuming Hardy-Weinberg. |
true_BETA0 |
A positive numeric value denoting the reference cell type
and reference base's expression multiplied by two and log transformed.
For example, if the TReC for reference base and cell type is 500, then
|
true_KAPPA |
A numeric vector denoting the baseline fold change in TReC between a cell type and reference. By definition, the first element is 1. |
true_ETA |
A numeric vector where each element denotes the fold change in TReC between the non-reference and reference base in a cell type. |
true_PHI |
A non-negative numeric value denoting the over-dispersion term
associated with TReC. If |
true_PSI |
A non-negative numeric value denoting the over-dispersion term
associated with ASReC. If |
prob_phased |
A positive numeric value denoting the simulated proportion of simulated TReC that are ASReC. |
true_ALPHA |
By default, it is set to |
batch |
A numeric value set to 1 by default to allow underlying batch effects. Set to zero to eliminate batch effects. |
RHO |
A numeric matrix of cell type proportions where each row sums to one.
If set to |
cnfSNP |
A boolean value where |
show |
A boolean value to display verbose output and plot intermediate simulated results. |
A R list containing true parameters governing the simulated dataset,
simulated covariate matrix XX, observed outcomes in dat.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.