| CSeQTL_linearTest | R Documentation |
Runs marginal and cell type-specific analysis using ordinary least squares.
CSeQTL_linearTest(
input,
XX,
RHO,
SNP,
YY = NULL,
MARG = FALSE,
impute_geno = FALSE,
trim = FALSE,
thres_TRIM = 10,
show_plot = TRUE,
main_plot = "",
CTs = NULL
)
input |
A data.frame containing columns |
XX |
A numeric design matrix of baseline covariates including the intercept in the first column and centered continuous covariates. |
RHO |
A numeric matrix of cell type proportions. Rows correspond to subjects and columns correspond to cell types. |
SNP |
An integer vector of phased genotypes coded 0 (AA), 1 (AB), 2 (BA), 3 (BB), and 5 (NA). |
YY |
Default is |
MARG |
Boolean value. Set to |
impute_geno |
Boolean value. Default is set to |
trim |
Boolean value set to |
thres_TRIM |
A positive numeric value to perform subject outcome trimming. Subjects with standardized Cooks' Distances greater than the threshold are trimmed. |
show_plot |
Boolean value set to |
main_plot |
Character string for the visual's main title. |
CTs |
Set to |
A R list containing lm() output for lm_out,
a R dataframe for out_df containing regression estimates,
standard errors, p-values. res_trim provides a summary of trimmed
results over a grid of cut-off values and number of samples trimmed.
cooksd is a numeric vector of median shifted and MAD scaled
Cook's distances per sample. prop_trim, a numeric value for
number of samples with outcome values trimmed for the user-specified
thres_TRIM value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.