Learn R Programming

CSeQTL (version 1.0.0)

gen_true_RHO: gen_true_RHO

Description

Simulates cell type proportions under three scenarios.

Usage

gen_true_RHO(wRHO = 1, NN, QQ, RHO = NULL)

Value

A numeric matrix with QQ columns and NN rows of cell type proportions per sample and cell type.

Arguments

wRHO

An integer taking values 1, 2, or 3 for one of the three scenarios. For wRHO equal to 2 or 3, QQ needs to be set to 3 cell types.

NN

Positive integer for sample size.

QQ

Positive integer for number of cell types.

RHO

Default to NULL leads to simulating cell type proportions. If a matrix of proportions is supplied, this function will append row/column names.