plot_RHO: plot_RHO

View source: R/CSeQTL.R

plot_RHOR Documentation

plot_RHO

Description

plot_RHO

Usage

plot_RHO(RHO, main_plot = "", ...)

Arguments

RHO

A numeric matrix of cell type proportions. Rows correspond to subjects and columns correspond to cell types.

main_plot

Character string for the visual's main title.

...

Arguments for plot(x,y,bty = "n",...).

Value

Null. A plot of cell type proportions per cell type across NN samples.


CSeQTL documentation built on April 24, 2026, 9:06 a.m.