Learn R Programming

CSeQTL (version 1.0.0)

prep_gene_info: prep_gene_info

Description

Prepare GTF files for gene and exon level information

Usage

prep_gene_info(work_dir, gtf_gz_fn = NULL)

Value

Null. No value returned.

Arguments

work_dir

A character string specifying the working directory to store gene and exon data.

gtf_gz_fn

A character string full path of the gz compressed gtf file