Learn R Programming

CSeQTL (version 1.0.0)

CSeQTL_run_MatrixEQTL: CSeQTL_run_MatrixEQTL

Description

CSeQTL_run_MatrixEQTL

Usage

CSeQTL_run_MatrixEQTL(TREC, RD, XX, SNP, out_cis_fn, cisDist = 1e+06)

Value

The MatrixEQTL output file/R dataframe generated containing genes, SNPs, associated p-values, effect sizes, etc.

Arguments

TREC

A matrix of integer total read counts, rows are genes with row labels with syntax "gene_name:chrom:start:end", columns are samples with column labels.

RD

A positive numeric vector of library sizes per sample.

XX

A numeric design matrix of baseline covariates including the intercept in the first column and centered continuous covariates.

SNP

An integer matrix, rows are genomic loci with row labels such as "chrom:pos", columns correspond to samples with column labels.

out_cis_fn

A full path filename string to store MatrixEQTL output

cisDist

A positive integer for number of SNPs to include relative to the gene body