CSeQTL_run_MatrixEQTL
CSeQTL_run_MatrixEQTL(TREC, RD, XX, SNP, out_cis_fn, cisDist = 1e+06)The MatrixEQTL output file/R dataframe generated containing genes, SNPs, associated p-values, effect sizes, etc.
A matrix of integer total read counts, rows are genes with row labels with syntax "gene_name:chrom:start:end", columns are samples with column labels.
A positive numeric vector of library sizes per sample.
A numeric design matrix of baseline covariates including the intercept in the first column and centered continuous covariates.
An integer matrix, rows are genomic loci with row labels such as "chrom:pos", columns correspond to samples with column labels.
A full path filename string to store MatrixEQTL output
A positive integer for number of SNPs to include relative to the gene body