| plot_RHO | R Documentation |
plot_RHO
plot_RHO(RHO, main_plot = "", ...)
RHO |
A numeric matrix of cell type proportions. Rows correspond to subjects and columns correspond to cell types. |
main_plot |
Character string for the visual's main title. |
... |
Arguments for |
Null. A plot of cell type proportions per cell type across NN samples.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.